@@ -34,7 +34,7 @@ import textwrap
 import time
 from typing import List
 
-__version__ = '1.2.0'
+__version__ = '1.2.1'
 __docformat__ = "restructuredtext"
 
 # format settings
@@ -498,13 +498,12 @@ def write_to_file(output_file, dot_output):
 
     """
     try:
-        f = open(output_file, 'wb+')
+        with open(output_file, 'wb+') as f:
+            f.write(dot_output)
+            f.flush()
+            os.fsync(f.fileno())
     except OSError as e:
-        barf(f"Could not open file '{output_file}':\n>>>{e}", EXIT_CODES["not_write_to_file"])
-    f.write(dot_output)
-    f.flush()
-    os.fsync(f.fileno())
-    f.close()
+        barf(f"Could not write to file '{output_file}':\n>>>{e}", EXIT_CODES["not_write_to_file"])
 
 
 def show_in_viewer(output_file, viewer):
@@ -1153,7 +1152,7 @@ def innermost_main(opts):
                 temporary_file.close()  # also removes the file
     elif output_settings[PROCESSED]:
         debug("Will now print dot processed output in format: '%s'" % output_settings[FORMAT])
-        print(dot_output)
+        sys.stdout.buffer.write(dot_output)
 
 
 def inner_main():
